# notcurses

Python bindings for the C [Notcurses](https://github.com/dankamongmen/notcurses)
library. Notcurses is a blingful library for building complex, vibrant textual
user interfaces (TUIs) on modern terminal emulators, of which these Python
bindings offer nowhere near complete coverage.

by [nick black](https://nick-black.com/dankwiki/index.php/Hack_on) (<nickblack@linux.com>)

for more information, see [my wiki](https://nick-black.com/dankwiki/index.php/Notcurses).

[![Build Status](https://drone.dsscaw.com:4443/api/badges/dankamongmen/notcurses/status.svg)](https://drone.dsscaw.com:4443/dankamongmen/notcurses)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
